Tutorials
========================================================================================

These pages contain a set of tutorial notebooks for working through core and more advanced TAPE
functionality.

.. toctree::

    Loading Data into TAPE <tutorials/tape_datasets>
    Working with the TAPE Ensemble object <tutorials/working_with_the_ensemble>
    Working with HiPSCat and LSDB data <tutorials/working_with_hipscat_and_lsdb>
    Working with the TAPE Timeseries object <tutorials/working_with_the_timeseries>
    Common Data Operations with TAPE <tutorials/common_data_operations>
    Working with Structure Function <tutorials/working_with_structure_function>
    Using Ray with the Ensemble <tutorials/using_ray_with_the_ensemble>
    Showcase - Binning Sources in the Ensemble <tutorials/binning_slowly_changing_sources>
    Showcase - Batch Function <tutorials/batch_showcase>
    Showcase - Structure Function <tutorials/structure_function_showcase>

